==> istio-model-v1alpha3-6.2.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterListenerMatchFilterChainMatchFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EnvoyFilterListenerMatchFilterChainMatchFluentImpl<A extends EnvoyFilterListenerMatchFilterChainMatchFluent<A>> extends BaseFluent<A> implements EnvoyFilterListenerMatchFilterChainMatchFluent<A>{
  public EnvoyFilterListenerMatchFilterChainMatchFluentImpl() {
  }
  public EnvoyFilterListenerMatchFilterChainMatchFluentImpl(EnvoyFilterListenerMatchFilterChainMatch instance) {
    this.withApplicationProtocols(instance.getApplicationProtocols()); 
    this.withDestinationPort(instance.getDestinationPort()); 
    this.withFilter(instance.getFilter()); 
    this.withName(instance.getName()); 
    this.withSni(instance.getSni()); 
    this.withTransportProtocol(instance.getTransportProtocol()); 
  }
  private String applicationProtocols;
  private Integer destinationPort;
  private EnvoyFilterListenerMatchFilterMatchBuilder filter;
  private String name;
  private String sni;
  private String transportProtocol;
  public String getApplicationProtocols() {
    return this.applicationProtocols;
  }
  public A withApplicationProtocols(String applicationProtocols) {
    this.applicationProtocols=applicationProtocols; return (A) this;
  }
  public Boolean hasApplicationProtocols() {
    return this.applicationProtocols != null;
  }
  public Integer getDestinationPort() {
    return this.destinationPort;
  }
  public A withDestinationPort(Integer destinationPort) {
    this.destinationPort=destinationPort; return (A) this;
  }
  public Boolean hasDestinationPort() {
    return this.destinationPort != null;
  }
  
  /**
   * This method has been deprecated, please use method buildFilter instead.
   * @return The buildable object.
   */
  @Deprecated
  public EnvoyFilterListenerMatchFilterMatch getFilter() {
    return this.filter!=null ?this.filter.build():null;
  }
  public EnvoyFilterListenerMatchFilterMatch buildFilter() {
    return this.filter!=null ?this.filter.build():null;
  }
  public A withFilter(EnvoyFilterListenerMatchFilterMatch filter) {
    _visitables.get("filter").remove(this.filter);
    if (filter!=null){ this.filter= new EnvoyFilterListenerMatchFilterMatchBuilder(filter); _visitables.get("filter").add(this.filter);} else { this.filter = null; _visitables.get("filter").remove(this.filter); } return (A) this;
  }
  public Boolean hasFilter() {
    return this.filter != null;
  }
  public EnvoyFilterListenerMatchFilterChainMatchFluent.FilterNested<A> withNewFilter() {
    return new EnvoyFilterListenerMatchFilterChainMatchFluentImpl.FilterNestedImpl();
  }
  public EnvoyFilterListenerMatchFilterChainMatchFluent.FilterNested<A> withNewFilterLike(EnvoyFilterListenerMatchFilterMatch item) {
    return new EnvoyFilterListenerMatchFilterChainMatchFluentImpl.FilterNestedImpl(item);
  }
  public EnvoyFilterListenerMatchFilterChainMatchFluent.FilterNested<A> editFilter() {
    return withNewFilterLike(getFilter());
  }
  public EnvoyFilterListenerMatchFilterChainMatchFluent.FilterNested<A> editOrNewFilter() {
    return withNewFilterLike(getFilter() != null ? getFilter(): new EnvoyFilterListenerMatchFilterMatchBuilder().build());
  }
  public EnvoyFilterListenerMatchFilterChainMatchFluent.FilterNested<A> editOrNewFilterLike(EnvoyFilterListenerMatchFilterMatch item) {
    return withNewFilterLike(getFilter() != null ? getFilter(): item);
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getSni() {
    return this.sni;
  }
  public A withSni(String sni) {
    this.sni=sni; return (A) this;
  }
  public Boolean hasSni() {
    return this.sni != null;
  }
  public String getTransportProtocol() {
    return this.transportProtocol;
  }
  public A withTransportProtocol(String transportProtocol) {
    this.transportProtocol=transportProtocol; return (A) this;
  }
  public Boolean hasTransportProtocol() {
    return this.transportProtocol != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EnvoyFilterListenerMatchFilterChainMatchFluentImpl that = (EnvoyFilterListenerMatchFilterChainMatchFluentImpl) o;
    if (applicationProtocols != null ? !applicationProtocols.equals(that.applicationProtocols) :that.applicationProtocols != null) return false;
    if (destinationPort != null ? !destinationPort.equals(that.destinationPort) :that.destinationPort != null) return false;
    if (filter != null ? !filter.equals(that.filter) :that.filter != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (sni != null ? !sni.equals(that.sni) :that.sni != null) return false;
    if (transportProtocol != null ? !transportProtocol.equals(that.transportProtocol) :that.transportProtocol != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(applicationProtocols,  destinationPort,  filter,  name,  sni,  transportProtocol,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (applicationProtocols != null) { sb.append("applicationProtocols:"); sb.append(applicationProtocols + ","); }
    if (destinationPort != null) { sb.append("destinationPort:"); sb.append(destinationPort + ","); }
    if (filter != null) { sb.append("filter:"); sb.append(filter + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (sni != null) { sb.append("sni:"); sb.append(sni + ","); }
    if (transportProtocol != null) { sb.append("transportProtocol:"); sb.append(transportProtocol); }
    sb.append("}");
    return sb.toString();
  }
  class FilterNestedImpl<N> extends EnvoyFilterListenerMatchFilterMatchFluentImpl<EnvoyFilterListenerMatchFilterChainMatchFluent.FilterNested<N>> implements EnvoyFilterListenerMatchFilterChainMatchFluent.FilterNested<N>,Nested<N>{
    FilterNestedImpl(EnvoyFilterListenerMatchFilterMatch item) {
      this.builder = new EnvoyFilterListenerMatchFilterMatchBuilder(this, item);
    }
    FilterNestedImpl() {
      this.builder = new EnvoyFilterListenerMatchFilterMatchBuilder(this);
    }
    EnvoyFilterListenerMatchFilterMatchBuilder builder;
    public N and() {
      return (N) EnvoyFilterListenerMatchFilterChainMatchFluentImpl.this.withFilter(builder.build());
    }
    public N endFilter() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterListenerMatchFilterChainMatchFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EnvoyFilterListenerMatchFilterChainMatchFluentImpl<A extends EnvoyFilterListenerMatchFilterChainMatchFluent<A>> extends BaseFluent<A> implements EnvoyFilterListenerMatchFilterChainMatchFluent<A>{
  public EnvoyFilterListenerMatchFilterChainMatchFluentImpl() {
  }
  public EnvoyFilterListenerMatchFilterChainMatchFluentImpl(EnvoyFilterListenerMatchFilterChainMatch instance) {
    if (instance != null) {
      this.withApplicationProtocols(instance.getApplicationProtocols());
      this.withDestinationPort(instance.getDestinationPort());
      this.withFilter(instance.getFilter());
      this.withName(instance.getName());
      this.withSni(instance.getSni());
      this.withTransportProtocol(instance.getTransportProtocol());
    }
  }
  private String applicationProtocols;
  private Integer destinationPort;
  private EnvoyFilterListenerMatchFilterMatchBuilder filter;
  private String name;
  private String sni;
  private String transportProtocol;
  public String getApplicationProtocols() {
    return this.applicationProtocols;
  }
  public A withApplicationProtocols(String applicationProtocols) {
    this.applicationProtocols=applicationProtocols; return (A) this;
  }
  public Boolean hasApplicationProtocols() {
    return this.applicationProtocols != null;
  }
  public Integer getDestinationPort() {
    return this.destinationPort;
  }
  public A withDestinationPort(Integer destinationPort) {
    this.destinationPort=destinationPort; return (A) this;
  }
  public Boolean hasDestinationPort() {
    return this.destinationPort != null;
  }
  
  /**
   * This method has been deprecated, please use method buildFilter instead.
   * @return The buildable object.
   */
  @Deprecated
  public EnvoyFilterListenerMatchFilterMatch getFilter() {
    return this.filter!=null ?this.filter.build():null;
  }
  public EnvoyFilterListenerMatchFilterMatch buildFilter() {
    return this.filter!=null ?this.filter.build():null;
  }
  public A withFilter(EnvoyFilterListenerMatchFilterMatch filter) {
    _visitables.get("filter").remove(this.filter);
    if (filter!=null){ this.filter= new EnvoyFilterListenerMatchFilterMatchBuilder(filter); _visitables.get("filter").add(this.filter);} else { this.filter = null; _visitables.get("filter").remove(this.filter); } return (A) this;
  }
  public Boolean hasFilter() {
    return this.filter != null;
  }
  public EnvoyFilterListenerMatchFilterChainMatchFluentImpl.FilterNested<A> withNewFilter() {
    return new EnvoyFilterListenerMatchFilterChainMatchFluentImpl.FilterNestedImpl();
  }
  public EnvoyFilterListenerMatchFilterChainMatchFluentImpl.FilterNested<A> withNewFilterLike(EnvoyFilterListenerMatchFilterMatch item) {
    return new EnvoyFilterListenerMatchFilterChainMatchFluentImpl.FilterNestedImpl(item);
  }
  public EnvoyFilterListenerMatchFilterChainMatchFluentImpl.FilterNested<A> editFilter() {
    return withNewFilterLike(getFilter());
  }
  public EnvoyFilterListenerMatchFilterChainMatchFluentImpl.FilterNested<A> editOrNewFilter() {
    return withNewFilterLike(getFilter() != null ? getFilter(): new EnvoyFilterListenerMatchFilterMatchBuilder().build());
  }
  public EnvoyFilterListenerMatchFilterChainMatchFluentImpl.FilterNested<A> editOrNewFilterLike(EnvoyFilterListenerMatchFilterMatch item) {
    return withNewFilterLike(getFilter() != null ? getFilter(): item);
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getSni() {
    return this.sni;
  }
  public A withSni(String sni) {
    this.sni=sni; return (A) this;
  }
  public Boolean hasSni() {
    return this.sni != null;
  }
  public String getTransportProtocol() {
    return this.transportProtocol;
  }
  public A withTransportProtocol(String transportProtocol) {
    this.transportProtocol=transportProtocol; return (A) this;
  }
  public Boolean hasTransportProtocol() {
    return this.transportProtocol != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EnvoyFilterListenerMatchFilterChainMatchFluentImpl that = (EnvoyFilterListenerMatchFilterChainMatchFluentImpl) o;
    if (!java.util.Objects.equals(applicationProtocols, that.applicationProtocols)) return false;

    if (!java.util.Objects.equals(destinationPort, that.destinationPort)) return false;

    if (!java.util.Objects.equals(filter, that.filter)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(sni, that.sni)) return false;

    if (!java.util.Objects.equals(transportProtocol, that.transportProtocol)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(applicationProtocols,  destinationPort,  filter,  name,  sni,  transportProtocol,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (applicationProtocols != null) { sb.append("applicationProtocols:"); sb.append(applicationProtocols + ","); }
    if (destinationPort != null) { sb.append("destinationPort:"); sb.append(destinationPort + ","); }
    if (filter != null) { sb.append("filter:"); sb.append(filter + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (sni != null) { sb.append("sni:"); sb.append(sni + ","); }
    if (transportProtocol != null) { sb.append("transportProtocol:"); sb.append(transportProtocol); }
    sb.append("}");
    return sb.toString();
  }
  class FilterNestedImpl<N> extends EnvoyFilterListenerMatchFilterMatchFluentImpl<EnvoyFilterListenerMatchFilterChainMatchFluentImpl.FilterNested<N>> implements EnvoyFilterListenerMatchFilterChainMatchFluentImpl.FilterNested<N>,Nested<N>{
    FilterNestedImpl(EnvoyFilterListenerMatchFilterMatch item) {
      this.builder = new EnvoyFilterListenerMatchFilterMatchBuilder(this, item);
    }
    FilterNestedImpl() {
      this.builder = new EnvoyFilterListenerMatchFilterMatchBuilder(this);
    }
    EnvoyFilterListenerMatchFilterMatchBuilder builder;
    public N and() {
      return (N) EnvoyFilterListenerMatchFilterChainMatchFluentImpl.this.withFilter(builder.build());
    }
    public N endFilter() {
      return and();
    }
    
  }
  
}
